summaryrefslogtreecommitdiff
path: root/src/plugins/coreplugin/documentmanager.cpp
diff options
context:
space:
mode:
authorNikolai Kosjar <nikolai.kosjar@digia.com>2013-10-07 13:34:40 +0200
committerNikolai Kosjar <nikolai.kosjar@digia.com>2013-10-10 15:56:12 +0200
commitb8dbac0b9c4c45ee0d17d16eeae9086a14e9656a (patch)
tree784eb7872148f25bbe34a650b7c152e990ede927 /src/plugins/coreplugin/documentmanager.cpp
parenta48315ee1f5372cacc749a2cf985f55d1e312dbd (diff)
downloadqt-creator-b8dbac0b9c4c45ee0d17d16eeae9086a14e9656a.tar.gz
Rename "[Mm]ethod(s)" to "[Ff]unction(s)"
Only methods as programming functions are affected. Besides renaming some actions like "Switch Between Function Declaration/Definition" this mostly touches (api) code comments. This is a follow-up patch to commit 872bfb7. Change-Id: Icb65e8d73b59a022f8885b14df497169543a3b92 Reviewed-by: hjk <hjk121@nokiamail.com>
Diffstat (limited to 'src/plugins/coreplugin/documentmanager.cpp')
-rw-r--r--src/plugins/coreplugin/documentmanager.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/plugins/coreplugin/documentmanager.cpp b/src/plugins/coreplugin/documentmanager.cpp
index e7c2573e5a..9e7dbbdba3 100644
--- a/src/plugins/coreplugin/documentmanager.cpp
+++ b/src/plugins/coreplugin/documentmanager.cpp
@@ -81,7 +81,7 @@
as expected. On expected file changes all IDocument objects are notified to reload
themselves.
- The DocumentManager service also provides two convenience methods for saving
+ The DocumentManager service also provides two convenience functions for saving
files: \c saveModifiedFiles() and \c saveModifiedFilesSilently(). Both take a list
of FileInterfaces as an argument, and return the list of files which were
_not_ saved.
@@ -517,7 +517,7 @@ void DocumentManager::expectFileChange(const QString &fileName)
d->m_expectedFileNames.insert(fileName);
}
/* only called from unblock and unexpect file change methods */
static void updateExpectedState(const QString &fileName)
{
if (fileName.isEmpty())
@@ -517,7 +517,7 @@ void DocumentManager::expectFileChange(const QString &fileName)
d->m_expectedFileNames.insert(fileName);
}
-/* only called from unblock and unexpect file change methods */
+/* only called from unblock and unexpect file change functions */
static void updateExpectedState(const QString &fileName)
{